@@ -29,12 +29,14 @@ def cli():
 @cli.command()
 @click.option('--host', default='0.0.0.0', help='服务器监听地址')
 @click.option('--port', default=8001, type=int, help='服务器监听端口')
+@click.option('--jettask-pg-url', envvar='JETTASK_PG_URL', 
+              default='postgresql://jettask:123456@localhost:5432/jettask',
+              help='PostgreSQL连接URL')
 @click.option('--reload', is_flag=True, default=False, help='启用自动重载')
 @click.option('--log-level', default='info', 
               type=click.Choice(['debug', 'info', 'warning', 'error']),
               help='日志级别')
-@click.option('--unified', is_flag=True, default=False, help='使用统一的API路由器（实验性）')
-def api(host, port, reload, log_level, unified):
+def api(host, port, jettask_pg_url, reload, log_level):
     """启动 API 服务和监控界面
     
     示例:
@@ -42,34 +44,26 @@ def api(host, port, reload, log_level, unified):
       # 使用默认配置启动
       jettask api
       
-      # 指定端口和主机
-      jettask api --host 0.0.0.0 --port 8080
+      # 指定端口和数据库
+      jettask api --host 0.0.0.0 --port 8080 --jettask-pg-url postgresql://user:pass@host/db
+      
+      # 通过环境变量配置
+      export JETTASK_PG_URL=postgresql://jettask:123456@localhost:5432/jettask
+      jettask api
       
       # 启用开发模式（自动重载）
       jettask api --reload --log-level debug
-      
-      # 使用旧版API（不推荐）
-      jettask api --no-unified
     """
     import os
     import uvicorn
     
-    # 设置环境变量（如果需要）
-    if not os.getenv('JETTASK_PG_URL'):
-        os.environ['JETTASK_PG_URL'] = 'postgresql://jettask:123456@localhost:5432/jettask'
+    # 设置环境变量（供应用内部使用）
+    os.environ['JETTASK_PG_URL'] = jettask_pg_url
+    os.environ['TASK_CENTER_PG_URL'] = jettask_pg_url  # 兼容旧版本配置名
     
-    if not os.getenv('JETTASK_CENTER_URL'):
-        os.environ['JETTASK_CENTER_URL'] = f'http://localhost:{port}/api/namespaces/default'
-    
-    # 选择使用的应用模块
-    if unified:
-        app_module = "jettask.webui.backend.main_unified:app"
-        click.echo(f"Starting JetTask API Server (Unified Mode - Experimental) on {host}:{port}")
-        click.echo("All API endpoints are consolidated in unified_api_router.py")
-        click.echo("NOTE: This mode requires specific database schema. Use --no-unified for production.")
-    else:
-        app_module = "jettask.webui.backend.main:app"
-        click.echo(f"Starting JetTask API Server on {host}:{port}")
+    # 使用标准应用模块
+    app_module = "jettask.webui.backend.main:app"
+    click.echo(f"Starting JetTask API Server on {host}:{port}")
     
     # 显示配置信息
     click.echo("=" * 60)
@@ -77,10 +71,12 @@ def api(host, port, reload, log_level, unified):
     click.echo("=" * 60)
     click.echo(f"Host:        {host}")
     click.echo(f"Port:        {port}")
-    click.echo(f"API Mode:    {'Unified' if unified else 'Legacy'}")
     click.echo(f"Auto-reload: {reload}")
     click.echo(f"Log level:   {log_level}")
-    click.echo(f"Database:    {os.getenv('JETTASK_PG_URL', 'Not configured')}")
+    click.echo(f"Database:    {jettask_pg_url}")
+    click.echo("=" * 60)
+    click.echo(f"API Endpoint: http://{host}:{port}/api")
+    click.echo(f"WebUI:        http://{host}:{port}/")
     click.echo("=" * 60)
     
     # 启动服务器
